---
name: Bug report
about: Create a report to help us improve
title: 'Bug'
labels: 'bug'
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Data that is used
2. TLS parameters
3. Which step or function in TLS fails?

**Desktop (please complete the following information):**
 - OS: [e.g. MacOS, Linux, Windows]
 - Python version [e.g. 3.7]
 - TLS Version [1.0.13]

**Additional context**
Add any other context about the problem here.
